@@ -45,7 +45,18 @@ inline char *toString(const bool &t)
 template<>
 inline bool qCompare(bool const &t1, bool const &t2, const char *actual, const char *expected, const char *file, int line)
 {
-    return compare_helper(t1 == t2, "Compared values are not the same", toString(t1), toString(t2), actual, expected, file, line);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+    auto formatter = Internal::genericToString<bool>;
+    return compare_helper(t1 == t2, "Compared values are not the same", &t1, &t2, formatter, formatter, actual, expected, file, line);
+#else
+    auto actualVal = [&t1] {
+        return toString(t1);
+    };
+    auto expectedVal = [&t2] {
+        return toString(t2);
+    };
+    return compare_helper(t1 == t2, "Compared values are not the same", actualVal, expectedVal, actual, expected, file, line);
+#endif
 }
 
 template<>
@@ -57,7 +68,18 @@ inline char *toString(const GpgME::Protocol &t)
 template<>
 inline bool qCompare(GpgME::Protocol const &t1, GpgME::Protocol const &t2, const char *actual, const char *expected, const char *file, int line)
 {
-    return compare_helper(t1 == t2, "Compared values are not the same", toString(t1), toString(t2), actual, expected, file, line);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+    auto formatter = Internal::genericToString<GpgME::Protocol>;
+    return compare_helper(t1 == t2, "Compared values are not the same", &t1, &t2, formatter, formatter, actual, expected, file, line);
+#else
+    auto actualVal = [&t1] {
+        return toString(t1);
+    };
+    auto expectedVal = [&t2] {
+        return toString(t2);
+    };
+    return compare_helper(t1 == t2, "Compared values are not the same", actualVal, expectedVal, actual, expected, file, line);
+#endif
 }
 }
 
@@ -133,6 +155,8 @@ GpgME::Key createTestKey(const char *uid,
     key->disabled = 0;
     key->can_encrypt = int(usage == KeyCache::KeyUsage::AnyUsage || usage == KeyCache::KeyUsage::Encrypt);
     key->can_sign = int(usage == KeyCache::KeyUsage::AnyUsage || usage == KeyCache::KeyUsage::Sign);
+    key->has_encrypt = int(usage == KeyCache::KeyUsage::AnyUsage || usage == KeyCache::KeyUsage::Encrypt);
+    key->has_sign = int(usage == KeyCache::KeyUsage::AnyUsage || usage == KeyCache::KeyUsage::Sign);
     key->secret = 1;
     key->uids->validity = mapValidity(validity);
     key->keylist_mode = GPGME_KEYLIST_MODE_VALIDATE;
@@ -141,6 +165,8 @@ GpgME::Key createTestKey(const char *uid,
     gpgme_subkey_t subkey;
     _gpgme_key_add_subkey(key, &subkey);
     subkey->is_de_vs = 1;
+    subkey->can_encrypt = key->can_encrypt;
+    subkey->can_sign = key->can_sign;
 
     return GpgME::Key(key, false);
 }
@@ -263,6 +289,13 @@ class NewKeyApprovalDialogTest : public QObject
     Q_OBJECT
 
 private Q_SLOTS:
+    void initTestCase()
+    {
+#ifdef Q_OS_WIN
+        QSKIP("UI tests don't run on Windows");
+#endif
+    }
+
     void init()
     {
         // hold a reference to the key cache to avoid rebuilding while the test is running
