@@ -21,11 +21,14 @@
 #include "enum.h"
 #include "keygroup.h"
 
+#include <libkleo/compat.h>
 #include <libkleo/compliance.h>
 #include <libkleo/formatting.h>
 #include <libkleo/gnupg.h>
 #include <libkleo/keycache.h>
+#include <libkleo/keyhelpers.h>
 
+#include "kleo/debug.h"
 #include <libkleo_debug.h>
 
 #include <gpgme++/key.h>
@@ -36,19 +39,9 @@ using namespace GpgME;
 namespace
 {
 
-QDebug operator<<(QDebug debug, const GpgME::Key &key)
-{
-    if (key.isNull()) {
-        debug << "Null";
-    } else {
-        debug << Formatting::summaryLine(key);
-    }
-    return debug.maybeSpace();
-}
-
 static inline bool ValidEncryptionKey(const Key &key)
 {
-    if (key.isNull() || key.isRevoked() || key.isExpired() || key.isDisabled() || !key.canEncrypt()) {
+    if (key.isNull() || key.isRevoked() || key.isExpired() || key.isDisabled() || !Kleo::keyHasEncrypt(key)) {
         return false;
     }
     return true;
@@ -56,7 +49,7 @@ static inline bool ValidEncryptionKey(const Key &key)
 
 static inline bool ValidSigningKey(const Key &key)
 {
-    if (key.isNull() || key.isRevoked() || key.isExpired() || key.isDisabled() || !key.canSign() || !key.hasSecret()) {
+    if (key.isNull() || key.isRevoked() || key.isExpired() || key.isDisabled() || !Kleo::keyHasSign(key) || !key.hasSecret()) {
         return false;
     }
     return true;
@@ -86,20 +79,6 @@ static int minimumValidity(const std::vector<Key> &keys, const QString &address)
     return minValidity <= UserID::Ultimate ? static_cast<UserID::Validity>(minValidity) : UserID::Unknown;
 }
 
-bool allKeysHaveProtocol(const std::vector<Key> &keys, Protocol protocol)
-{
-    return std::all_of(keys.cbegin(), keys.cend(), [protocol](const Key &key) {
-        return key.protocol() == protocol;
-    });
-}
-
-bool anyKeyHasProtocol(const std::vector<Key> &keys, Protocol protocol)
-{
-    return std::any_of(std::begin(keys), std::end(keys), [protocol](const Key &key) {
-        return key.protocol() == protocol;
-    });
-}
-
 } // namespace
 
 class KeyResolverCore::Private
@@ -159,11 +138,9 @@ bool KeyResolverCore::Private::isAcceptableSigningKey(const Key &key)
     if (!ValidSigningKey(key)) {
         return false;
     }
-    if (DeVSCompliance::isCompliant()) {
-        if (!Formatting::isKeyDeVs(key)) {
-            qCDebug(LIBKLEO_LOG) << "Rejected sig key" << key.primaryFingerprint() << "because it is not de-vs compliant.";
-            return false;
-        }
+    if (DeVSCompliance::isCompliant() && !DeVSCompliance::keyIsCompliant(key)) {
+        qCDebug(LIBKLEO_LOG) << "Rejected sig key" << key.primaryFingerprint() << "because it is not de-vs compliant.";
+        return false;
     }
     return true;
 }
@@ -174,15 +151,14 @@ bool KeyResolverCore::Private::isAcceptableEncryptionKey(const Key &key, const Q
         return false;
     }
 
-    if (DeVSCompliance::isCompliant()) {
-        if (!Formatting::isKeyDeVs(key)) {
-            qCDebug(LIBKLEO_LOG) << "Rejected enc key" << key.primaryFingerprint() << "because it is not de-vs compliant.";
-            return false;
-        }
+    if (DeVSCompliance::isCompliant() && !DeVSCompliance::keyIsCompliant(key)) {
+        qCDebug(LIBKLEO_LOG) << "Rejected enc key" << key.primaryFingerprint() << "because it is not de-vs compliant.";
+        return false;
     }
 
     if (address.isEmpty()) {
-        return true;
+        // group key must satisfy minimum validity for all user IDs
+        return Kleo::minimalValidityOfNotRevokedUserIDs(key) >= mMinimumValidity;
     }
     for (const auto &uid : key.userIDs()) {
         if (uid.addrSpec() == address.toStdString()) {
@@ -357,8 +333,12 @@ void KeyResolverCore::Private::resolveSigningGroups()
         }
         protocolKeysMap[CMS] = resolveSenderWithGroup(mSender, CMS);
     } else {
-        protocolKeysMap[OpenPGP] = resolveSenderWithGroup(mSender, OpenPGP);
-        protocolKeysMap[CMS] = resolveSenderWithGroup(mSender, CMS);
+        if (protocolKeysMap[OpenPGP].empty()) {
+            protocolKeysMap[OpenPGP] = resolveSenderWithGroup(mSender, OpenPGP);
+        }
+        if (protocolKeysMap[CMS].empty()) {
+            protocolKeysMap[CMS] = resolveSenderWithGroup(mSender, CMS);
+        }
     }
 }
 
