@@ -7,20 +7,21 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include <config-libkleo.h>
+
 #include "keyrearrangecolumnsproxymodel.h"
 
-#include "kleo/keygroup.h"
+#include <libkleo/keygroup.h>
 
 #include <gpgme++/key.h>
 
 using namespace Kleo;
 using namespace GpgME;
 
-KeyRearrangeColumnsProxyModel::KeyRearrangeColumnsProxyModel(QObject *parent) :
-    KRearrangeColumnsProxyModel(parent),
-    KeyListModelInterface()
+KeyRearrangeColumnsProxyModel::KeyRearrangeColumnsProxyModel(QObject *parent)
+    : KRearrangeColumnsProxyModel(parent)
+    , KeyListModelInterface()
 {
-
 }
 
 KeyListModelInterface *KeyRearrangeColumnsProxyModel::klm() const
@@ -58,7 +59,7 @@ QModelIndex KeyRearrangeColumnsProxyModel::index(const GpgME::Key &key) const
 QList<QModelIndex> KeyRearrangeColumnsProxyModel::indexes(const std::vector<GpgME::Key> &keys) const
 {
     QList<QModelIndex> myIdxs;
-    const QList <QModelIndex> srcIdxs = klm()->indexes(keys);
+    const QList<QModelIndex> srcIdxs = klm()->indexes(keys);
     myIdxs.reserve(srcIdxs.count());
     for (const QModelIndex &idx : srcIdxs) {
         myIdxs << mapFromSource(idx);
