@@ -17,6 +17,7 @@
 #include "progressdialog.h"
 
 #include <libkleo/algorithm.h>
+#include <libkleo/applicationpalettewatcher.h>
 #include <libkleo/compliance.h>
 #include <libkleo/debug.h>
 #include <libkleo/defaultkeyfilter.h>
@@ -34,6 +35,7 @@
 
 #include <QGpgME/Protocol>
 #include <QGpgME/QuickJob>
+#include <qgpgme/qgpgme_version.h>
 
 #include <QButtonGroup>
 #include <QCheckBox>
@@ -318,6 +320,9 @@ public:
         connect(mFormatBtns, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), q, [this]() {
             updateOkButton();
         });
+        connect(&appPaletteWatcher, &ApplicationPaletteWatcher::paletteChanged, q, [this]() {
+            updateOkButton();
+        });
 
         fmtLayout->addStretch(-1);
         fmtLayout->addWidget(pgpBtn);
@@ -410,7 +415,11 @@ public:
             qCWarning(LIBKLEO_LOG) << "new-style connect failed; connecting to QGpgME::QuickJob::result the old way";
             connect(job, SIGNAL(result(const GpgME::Error &)), q, SLOT(handleKeyGenResult()));
         }
+#if QGPGME_VERSION >= QT_VERSION_CHECK(2, 0, 0)
+        job->startCreate(addr);
+#else
         job->startCreate(addr, nullptr);
+#endif
         return;
     }
 
@@ -869,6 +878,7 @@ public:
         mComplianceLbl->setVisible(!doNotSign);
     }
 
+    ApplicationPaletteWatcher appPaletteWatcher;
     GpgME::Protocol mForcedProtocol;
     QList<KeySelectionCombo *> mSigningCombos;
     QList<KeySelectionCombo *> mEncCombos;
