@@ -111,14 +111,30 @@ bool Kleo::DeVSCompliance::keyIsCompliant(const GpgME::Key &key)
 
 const std::vector<std::string> &Kleo::DeVSCompliance::compliantAlgorithms()
 {
-    static const std::vector<std::string> compliantAlgos = {
-        "brainpoolP256r1",
-        "brainpoolP384r1",
-        "brainpoolP512r1",
-        "rsa3072",
-        "rsa4096",
+    static std::vector<std::string> compliantAlgos;
+    if (!isActive()) {
+        return Kleo::availableAlgorithms();
+    }
+    if (compliantAlgos.empty()) {
+        compliantAlgos.reserve(7);
+        compliantAlgos = {
+            "brainpoolP256r1",
+            "brainpoolP384r1",
+            "brainpoolP512r1",
+            "rsa3072",
+            "rsa4096",
+        };
+#if GPGMEPP_SUPPORTS_KYBER
+        if (engineIsVersion(2, 5, 2)) {
+            compliantAlgos.insert(compliantAlgos.end(),
+                                  {
+                                      "ky768_bp256",
+                                      "ky1024_bp384",
+                                  });
+        }
+#endif
     };
-    return isActive() ? compliantAlgos : Kleo::availableAlgorithms();
+    return compliantAlgos;
 }
 
 const std::vector<std::string> &Kleo::DeVSCompliance::preferredCompliantAlgorithms()
@@ -144,16 +160,14 @@ void Kleo::DeVSCompliance::decorate(QPushButton *button, bool compliant)
     }
     if (compliant) {
         button->setIcon(QIcon::fromTheme(QStringLiteral("security-high")));
-        if (!SystemInfo::isHighContrastModeActive()) {
-            const auto bgColor = KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::PositiveBackground).color().name();
-            button->setStyleSheet(QStringLiteral("QPushButton { background-color: %1; };").arg(bgColor));
-        }
+        auto buttonPalette = button->palette();
+        KColorScheme::adjustBackground(buttonPalette, KColorScheme::PositiveBackground, button->backgroundRole(), KColorScheme::Button);
+        button->setPalette(buttonPalette);
     } else {
         button->setIcon(QIcon::fromTheme(QStringLiteral("security-medium")));
-        if (!SystemInfo::isHighContrastModeActive()) {
-            const auto bgColor = KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NegativeBackground).color().name();
-            button->setStyleSheet(QStringLiteral("QPushButton { background-color: %1; };").arg(bgColor));
-        }
+        auto buttonPalette = button->palette();
+        KColorScheme::adjustBackground(buttonPalette, KColorScheme::NegativeBackground, button->backgroundRole(), KColorScheme::Button);
+        button->setPalette(buttonPalette);
     }
 }
 
